# Table of Contents

- [collibra-integration](<./collibra-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Collibra Integration](<./Collibra-Integration.md>)
  - [Overview](<./Collibra-Integration/Overview.md>)
  - [Benefits](<./Collibra-Integration/Benefits.md>)
  - [Scope of Integration: Data Synchronization Between Collibra and SAP LeanIX](<./Collibra-Integration/Scope-of-Integration-Data-Synchronization-Between-Collibra-and-SAP-LeanIX.md>)
  - [Best Practices and Essential Concepts](<./Collibra-Integration/Best-Practices-and-Essential-Concepts.md>)
  - [Define the Sync Scope](<./Collibra-Integration/Define-the-Sync-Scope.md>)
  - [Establish Clear Sources of Truth](<./Collibra-Integration/Establish-Clear-Sources-of-Truth.md>)
  - [Focus on the Conceptual Data Layer](<./Collibra-Integration/Focus-on-the-Conceptual-Data-Layer.md>)
  - [Create A Dedicated User Account for Integration](<./Collibra-Integration/Create-A-Dedicated-User-Account-for-Integration.md>)
  - [Establish Clear Responsibilities and Collaboration](<./Collibra-Integration/Establish-Clear-Responsibilities-and-Collaboration.md>)
  - [Key Concepts and Their Mapping](<./Collibra-Integration/Key-Concepts-and-Their-Mapping.md>)
  - [Recommended Workflow for SAP LeanIX and Collibra Integration](<./Collibra-Integration/Recommended-Workflow-for-SAP-LeanIX-and-Collibra-Integration.md>)
  - [Accessing Linked Collibra Entities](<./Collibra-Integration/Accessing-Linked-Collibra-Entities.md>)
  - [Was this page helpful?](<./Collibra-Integration/Was-this-page-helpful.md>)
